@@ -27,7 +27,7 @@ method is implemented croak()ing if it's called.
 
 =head1 DEPENDENCIES
 
-This module wraps L<Selenium::Remote::Driver>, version 2.
+
 
 =cut
 
@@ -263,6 +263,8 @@ sub get_text {
 
 =item set_attribute($element_id, $attribute_name, $value)
 
+DEPRECATED
+
 Changes the value of the attribute named by C<$attribute_name> to C<$value>
 for the element identified by C<$element_id>.
 
@@ -274,6 +276,10 @@ sub set_attribute {
 
 =item get_selected($element_id)
 
+DEPRECATED
+
+Please use C<$self->get_attribute('selected')> instead.
+
 =cut
 
 sub get_selected {
@@ -282,6 +288,10 @@ sub get_selected {
 
 =item set_selected($element_id, $value)
 
+DEPRECATED
+
+Please use C<$self->set_attribute('selected', $value)> instead.
+
 =cut
 
 sub set_selected {
